==> fmutool-1.7.tar.gz: fmutool-1.7/fmutool/checker.py <==
import importlib.util
import inspect
import os
import glob
import xmlschema
from xmlschema.validators.exceptions import XMLSchemaValidationError
from .fmu_operations import OperationAbstract


class OperationGenericCheck(OperationAbstract):
    SUPPORTED_FMI_VERSIONS = ('2.0',)

    def __init__(self):
        self.compliant_with_version = None

    def __repr__(self):
        return f"FMU Generic Conformity Checks"

    def fmi_attrs(self, attrs):
        if attrs['fmiVersion'] not in self.SUPPORTED_FMI_VERSIONS:
            print(f"ERROR: fmutool only support FMI {','.join(self.SUPPORTED_FMI_VERSIONS)} versions.")
            return

        xsd_filename = os.path.join(os.path.dirname(__file__), "resources", "fmi-" + attrs['fmiVersion'],
                                    "fmi2ModelDescription.xsd")
        try:
            xmlschema.validate(self.fmu.descriptor_filename, schema=xsd_filename)
        except XMLSchemaValidationError as error:
            print(error.reason, error.msg)
        else:
            self.compliant_with_version = attrs['fmiVersion']

    def closure(self):
        if self.compliant_with_version:
            print(f"INFO: This FMU seems to be compliant with FMI-{self.compliant_with_version}.")
        else:
            print(f"ERROR: This FMU does not validate with FMI standard.")


checker_list = [OperationGenericCheck]


def _add_checkers_from_file(checker_filename: str):
    spec = importlib.util.spec_from_file_location(checker_filename, checker_filename)
    if not spec:
        print(f"ERROR: Cannot load {checker_filename}. Is this a python file?")
        return
    try:
        checker_module = importlib.util.module_from_spec(spec)
        try:
            spec.loader.exec_module(checker_module)
        except (ModuleNotFoundError, SyntaxError) as error:
            print(f"ERROR: Cannot load {checker_filename}: {error})")
            return

        for checker_name, checker_class in inspect.getmembers(checker_module, inspect.isclass):
            if OperationAbstract in checker_class.__bases__:
                checker_list.append(checker_class)
                print(f"Adding checker: {checker_filename}|{checker_name}")

    except AttributeError:
        print(f"ERROR: {checker_filename} should implement class 'OperationCheck'")


def _add_checkers(variable_name: str):
    checkers_folder = os.getenv(variable_name)
    if checkers_folder:
        if os.path.isdir(checkers_folder):
            for filename in glob.glob(os.path.join(checkers_folder, "*.py")):
                _add_checkers_from_file(filename)
        else:
            print(f"ERROR: {variable_name} should point to a valid folder.")


_add_checkers("FMUTOOL_CHECKER_DIR")

==> fmutool-1.7.4.tar.gz: fmutool-1.7.4/fmutool/checker.py <==
import importlib.util
import inspect
import os
import glob
import xmlschema
from xmlschema.validators.exceptions import XMLSchemaValidationError
from .fmu_operations import OperationAbstract


class OperationGenericCheck(OperationAbstract):
    SUPPORTED_FMI_VERSIONS = ('2.0',)

    def __init__(self):
        self.compliant_with_version = None

    def __repr__(self):
        return f"FMU Generic Conformity Checks"

    def fmi_attrs(self, attrs):
        if attrs['fmiVersion'] not in self.SUPPORTED_FMI_VERSIONS:
            print(f"ERROR: fmutool only support FMI {','.join(self.SUPPORTED_FMI_VERSIONS)} versions.")
            return

        xsd_filename = os.path.join(os.path.dirname(__file__), "resources", "fmi-" + attrs['fmiVersion'],
                                    "fmi2ModelDescription.xsd")
        try:
            xmlschema.validate(self.fmu.descriptor_filename, schema=xsd_filename)
        except XMLSchemaValidationError as error:
            print(error.reason, error.msg)
        else:
            self.compliant_with_version = attrs['fmiVersion']

    def closure(self):
        if self.compliant_with_version:
            print(f"INFO: This FMU seems to be compliant with FMI-{self.compliant_with_version}.")
        else:
            print(f"ERROR: This FMU does not validate with FMI standard.")


checker_list = [OperationGenericCheck]


def add_from_file(checker_filename: str):
    spec = importlib.util.spec_from_file_location(checker_filename, checker_filename)
    if not spec:
        print(f"ERROR: Cannot load {checker_filename}. Is this a python file?")
        return
    try:
        checker_module = importlib.util.module_from_spec(spec)
        try:
            spec.loader.exec_module(checker_module)
        except (ModuleNotFoundError, SyntaxError) as error:
            print(f"ERROR: Cannot load {checker_filename}: {error})")
            return

        for checker_name, checker_class in inspect.getmembers(checker_module, inspect.isclass):
            if OperationAbstract in checker_class.__bases__:
                checker_list.append(checker_class)
                print(f"Adding checker: {checker_filename}|{checker_name}")

    except AttributeError:
        print(f"ERROR: {checker_filename} should implement class 'OperationCheck'")
